@@ -27,6 +27,7 @@
           - do not overwrite existing image files
           - few optimizations into MSSLinux::get_pixels()
           - few optimizations into MSSImage::png()
+    0.0.4 - MSSLinux: use of memoization => huge time/operations gains
 
     You can always get the latest version of this module at:
 
@@ -38,7 +39,7 @@
 from __future__ import (unicode_literals, absolute_import,
                         division, print_function)
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 __author__ = "Mickaël 'Tiger-222' Schoentgen"
 __copyright__ = '''
     Copyright (c) 2013, Mickaël 'Tiger-222' Schoentgen
@@ -530,23 +531,14 @@ class MSSLinux(MSS):
         if image is None:
             raise ValueError('MSSLinux: XGetImage() failed.')
 
-        # TODO: how to optimize this part? pixels[offset:offset+3] is too long.
-        '''
-        pixels = [b'0'] * (3 * width * height)
-        for x in range(width):
-            for y in range(height):
-                pixel = self.XGetPixel(image, x, y)
-                blue = pixel & 255
-                green = (pixel & 65280) >> 8
-                red = (pixel & 16711680) >> 16
-                offset = (x + width * y) * 3
-                pixels[offset:offset+3] = b(red), b(green), b(blue)
-        #'''
-
-        # This code is a little bit better (19% faster)
+        resultats = {}
         def pix(pixel):
-            ''' Apply shifts to a pixel to get the RGB values. '''
-            return b((pixel & 16711680) >> 16) + b((pixel & 65280) >> 8) + b(pixel & 255)
+            ''' Apply shifts to a pixel to get the RGB values.
+                This method uses of memoization.
+            '''
+            if not pixel in resultats:
+                resultats[pixel] = b((pixel & 16711680) >> 16) + b((pixel & 65280) >> 8) + b(pixel & 255)
+            return resultats[pixel]
 
         get_pix = self.XGetPixel
         pixels = [pix(get_pix(image, x, y)) for y in range(height) for x in range(width)]
